#include <ncurses.h>
#include <stdlib.h>
#include <unistd.h>
#include "ncdrawlib.h"
#include <ppm.h>

int calcColour(int r, int g, int b);
void draw(int xpos,int ypos,int cols, int rows,pixel **data);

int main(int argc, char *argv[])
{
int cols,rows;
pixval maxval;
pixel **data;
int xpos,ypos;
int key;
FILE *fp;

if (argc!=2)
	{
	fprintf(stderr,"\nUsage: ncpicview file.ppm\n\n");
	exit(0);
	}

if ((fp = fopen(argv[1],"r"))==NULL)
	{
	fprintf(stderr,"\nBad file: %s\n\n", argv[1]);
	exit(-1);
	}

initDisplay();

init_pair(1, COLOR_BLACK, COLOR_BLACK);
init_pair(2, COLOR_BLACK, COLOR_RED);
init_pair(3, COLOR_BLACK, COLOR_GREEN);
init_pair(4, COLOR_BLACK, COLOR_YELLOW);
init_pair(5, COLOR_BLACK, COLOR_BLUE);
init_pair(6, COLOR_BLACK, COLOR_MAGENTA);
init_pair(7, COLOR_BLACK, COLOR_CYAN);
init_pair(8, COLOR_BLACK, COLOR_WHITE);

if ((data = ppm_readppm(fp,&cols,&rows,&maxval))==NULL)
	{
	fprintf(stderr,"\nBroken ppm file: %s\n\n",argv[1]);
	exit(-1);
	}
fclose(fp);

draw(0,0,cols,rows,data);

xpos = ypos = 0;
while((key = cursGetch(NULL))!='q')
	{
	switch(key)
		{
		case 'i':
		if (ypos>0) ypos--;
		draw(xpos,ypos,cols,rows,data);
		break;
		
		case 'k':
		if (ypos<rows) ypos++;
		draw(xpos,ypos,cols,rows,data);
		break;

		case 'l':
		if (xpos<cols) xpos++;
		draw(xpos,ypos,cols,rows,data);
		break;
		
		case 'j':
		if (ypos>0) xpos--;
		draw(xpos,ypos,cols,rows,data);
		break;	
		}
	}

closeDisplay();

return 0;
}

int calcColour(int r, int g, int b)
{
int colour=0;
float re,ge,be;
int i;

for (i=0;i<8;i++)
	{
	re = r/255.0;
	ge = g/255.0;
	be = b/255.0;

	colour = (int)(re*4.0 + be*2.0 + ge);
	}
return colour;
}

void draw(int xpos,int ypos,int cols, int rows,pixel **data)
{
int x,y;
int r,g,b,colour;

for(x=xpos;x<xpos+160;x++)
	{
	for(y=ypos;y<ypos+24;y++)
		{
		r = PPM_GETR(data[y][x/2]);
		g = PPM_GETG(data[y][x/2]);
		b = PPM_GETB(data[y][x/2]);

		colour = calcColour(r,g,b)+1;

		attron(COLOR_PAIR(colour));
		mvaddch(y-ypos, x-xpos, ' ');
		attroff(COLOR_PAIR(colour));			
		}
	}
refresh();
}
